SystemOrganization addCategory: #'Seaside-Tests-Email'!

!WAPackage class methodsFor: '*seaside-tests-email' stamp: 'lr 10/23/2008 21:32'!
seasideTestsEmail
	^ self new
		name: 'Seaside-Tests-Email';
		description: 'Unit tests for the package Seaside-Email.';
		addDependency: 'Seaside-Email';
		addDependency: 'Seaside-Tests-Core';
		yourself! !

TestCase subclass: #WAEmailAddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAEmailAddressTest methodsFor: 'private' stamp: 'pmm 9/2/2008 14:16'!
render: anObject
	^WARenderCanvas builder render: [ :html |
		html render: anObject ]! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:06'!
testAddress
	| address |
	address := WAEmailAddress address: 'philippe.marschall@gmail.com'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username isNil.
	self assert: address seasideString = 'philippe.marschall@gmail.com'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 9/2/2008 14:15'!
testAddressUsername
	| address |
	address := WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username = 'Philippe Marschall'.
	self assert: address seasideString = '"Philippe Marschall" <philippe.marschall@gmail.com>'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:39'!
testEmpty
	| address |
	address := WAEmailAddress address: (String with: Character cr with: Character lf), 'philippe.marschall@gmail.com'.
	self assert: address address = ''.
	self assert: address username isNil.
	self assert: address seasideString = ''.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:26'!
testInjection
	| address |
	address := WAEmailAddress address: 'philippe.marschall@gmail.com',
		(String with: Character cr with: Character lf),
		'Evil-Header: evil-value'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username isNil.
	self assert: address seasideString = 'philippe.marschall@gmail.com'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 9/2/2008 14:17'!
testRendering
	| address |
	address := WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username = 'Philippe Marschall'.
	self assert: (self render: address) = 'Philippe Marschall <philippe.marschall@gmail.com>'.! !

TestCase subclass: #WAEmailMessageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAEmailMessageTest methodsFor: 'private' stamp: 'pmm 8/31/2008 13:48'!
philippeMarschall
	^WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'! !

!WAEmailMessageTest methodsFor: 'private' stamp: 'pmm 8/31/2008 13:49'!
seasideDev
	^WAEmailAddress
		address: 'seaside-dev@lists.squeakfoundation.org'
		username: 'Seaside Developers Mailinglist'! !

!WAEmailMessageTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 15:35'!
testFromToSubjectBody
	| message cr |
	cr := String with: Character cr.
	message := WAEmailMessage
		from: self philippeMarschall
		to: self seasideDev
		subject: 'new email package'.
	message setStringBody: 'Hello' wrap: false.
		
	self assert:
'From: "Philippe Marschall" <philippe.marschall@gmail.com>', cr,
'To: "Seaside Developers Mailinglist" <seaside-dev@lists.squeakfoundation.org>',cr ,
'Subject: new email package', cr, cr,
'Hello' = message plainMessage! !

TestCase subclass: #WAStringEmailBodyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Email'!

!WAStringEmailBodyTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 15:40'!
testCrLf
	| cr lf crlf body |
	cr := String with: Character cr.
	lf := String with: Character lf.
	crlf := cr, lf.
	body := WAStringEmailBody string: 'hello', crlf, 'world'.
	self assert: 'hello', cr, 'world' = body seasideString! !

!WAStringEmailBodyTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 19:00'!
testSplitIntoLines
	| cr toSplit actual |
	cr := String with: Character cr.
	
	toSplit := cr, cr, 'a', cr, cr.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 5.
	#('' '' 'a' '' '') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].
	
	toSplit := cr, cr, 'a', cr.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 4.
	#('' '' 'a' '') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].
	
	toSplit := cr, cr, 'a'.
	actual := WAStringEmailBody splitIntoLines: toSplit.
	self assert: actual size = 3.
	#('' '' 'a') keysAndValuesDo: [ :index :expected |
		self assert: (actual at: index) = expected ].! !

!WAStringEmailBodyTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 17:41'!
testWrapping
	| cr body lf crlf |
	cr := String with: Character cr.
	lf := String with: Character lf.
	crlf := cr, lf.
	body := WAStringEmailBody
		string: '1111 222 2 33'
		lineLength: 5.
	self assert: '1111', cr, '222 2',cr, '33' = body seasideString.
	
	body := WAStringEmailBody
		string: '0123456789'
		lineLength: 5.	
	self assert: '01234', cr, '56789' = body seasideString.
	
	body := WAStringEmailBody
		string: '012345678'
		lineLength: 5.	
	self assert: '01234', cr, '5678' = body seasideString.
	
	body := WAStringEmailBody
		string: '01234567890'
		lineLength: 5.	
	self assert: '01234', cr, '56789', cr, '0' = body seasideString.
	
	body := WAStringEmailBody
		string: '0123456789', crlf, crlf, '0123456789'
		lineLength: 5.
	self assert: '01234', cr, '56789', cr, cr, '01234', cr, '56789' = body seasideString.! !
